class CurrencyQuote::Currency
	require 'open-uri'
	require 'nokogiri'
	require 'date'

	attr_accessor :currency, :date, :dolar, :doc, :sell, :buy, :quote

	BASE_URL = "https://www.bcra.gob.ar/publicacionesestadisticas/Cotizaciones_por_fecha_2.asp"
	
	def initialize(currency:, date: )
		@currency = currency
		@date 	  = date
		@dolar 	  = dolar
	end

	def get_quotation
		begin
			get_dolar_quotation
			make_get_to_bcra
			get_currency_quotation
		rescue Timeout::Error => e
			@sell = @buy = @quote = 0
		end
		return struct
	end

	private

		def get_dolar_quotation
			@dolar = CurrencyQuote::Dolar.new(date: date).get_quotation
		end

		def make_get_to_bcra
			url  = "#{BASE_URL}?date2=#{date}"
			@doc = Nokogiri::HTML( open(url) )
		end

		def get_currency_quotation
			data  = @doc.css("td").map(&:text).collect(&:strip!)
			index = data.index(currency)
			if index
				pass = data[index + 1].gsub(",", ".").to_f
				@quote = data[index + 2].gsub(",", ".").to_f
				pass = 1.0 if pass == 0
				@sell = (dolar.sell * pass).to_f
				@buy  = (dolar.buy * pass).to_f
			else
				@sell = @buy = @quote = 0
			end
		end

		def struct
			s = Struct.new(:currency, :date, :sell, :buy, :quote)
			s.new(currency, date, sell, buy, quote)
		end
end