class CurrencyQuote::Dolar
	require 'open-uri'
	require 'nokogiri'
	require 'date'
	require "addressable/uri"

	attr_accessor :date, :doc, :sell, :buy

	BASE_URL = "https://www.bna.com.ar/Cotizador/HistoricoPrincipales"

	def initialize(date:)
		@date = date
	end

	def get_quotation
		begin
			make_get_to_bna
			extract_data
		rescue Timeout::Error => e
			@data = @sell = @buy = 0
		end
		return struct
	end

	private

		def make_get_to_bna
			params = Addressable::URI.new
			params.query_values = {
				id: 'billetes',
				fecha: date,
				filtroEuro: 0,
				filtroDolar: 1
			}
			url = "#{BASE_URL}?#{params.query}"

			@doc = Nokogiri::HTML( open(url) )
		end

		def extract_data
			data = @doc.css("td").map(&:text)
			if data.empty?
				@data = @sell = @buy = 0
			else
				@date = data[data.size - 1]
				@sell = data[data.size - 2].gsub(",", ".").to_f
				@buy  = data[data.size - 3].gsub(",", ".").to_f
			end
		end

		def struct
			s = Struct.new(:date, :sell, :buy)
			s.new(date, sell, buy)
		end
end